//
//  ContentView.swift
//  CoreImageFiltersDemo
//
//  Created by Gabriel Theodoropoulos.
//  https://serialcoder.dev
//

import SwiftUI

struct ContentView: View {
    @State var selectedFilter = Filters.none
    @StateObject var filterMaker = FilterMaker()
    
    var body: some View {
        VStack {
            Image(uiImage: filterMaker.image)
                .resizable()
                .frame(height: 250)
                .scaledToFit()
            
            Picker("", selection: $selectedFilter) {
                ForEach(Filters.allCases, id: \.self) { filter in
                    Text(filter.description)
                }
            }
            .padding(.top)
            
            Button {
                filterMaker.chainFilters()
            } label: {
                Text("Chain Filters")
            }
            .padding(.top)

        }
        .padding()
        .onChange(of: selectedFilter) { newValue in
            switch newValue {
                case .none: filterMaker.removeFilter()
                case .sepia: filterMaker.applySepia()
                case .motionBlur: filterMaker.applyMotionBlur()
                case .colorInvert: filterMaker.applyColorInvert()
                case .crystallize: filterMaker.applyCrystallize()
                case .comic: filterMaker.applyComicEffect()
            }
        }
    }
}

struct ContentView_Previews: PreviewProvider {
    static var previews: some View {
        ContentView()
    }
}
